@@ -18,7 +18,7 @@ SIGNAL(SIG_ADC) {
 	unsigned char adlow,adhigh;
 	adlow=inp(ADCL); /* read low first !! */
 	adhigh=inp(ADCH); /* read low first !! */
-	analog_result=(adhigh<<4)|(adlow&0x0F);
+	analog_result=(adhigh<<8)|(adlow&0xFF);
 	analog_busy=0;
 }
 
@@ -39,7 +39,7 @@ int convertanalog(unsigned char channel)
         */
         outp((1<<ADEN)|(1<<ADIE)|(1<<ADIF)|(1<<ADPS2)|(1<<ADPS2),ADCSR);
 
-	outp(channel&0x08,ADMUX); /* write only the lower 3 bits */
+	outp(channel&0x07,ADMUX); /* write only the lower 3 bits */
 	/*  start conversion */
 	sbi(ADCSR,ADSC);
 	while(analog_busy); /* wait for result */
